Post-processing pass: align :: in consecutive declaration lines.
Groups consecutive lines that:
- Have the same indentation level
- Are declaration lines (start with a type keyword and contain
::) - Are not separated by blank lines, comments, or non-declaration lines
Within each group, pads the space before :: so all :: appear at the same column.
Functions
- align_
declarations - Align
::in consecutive declaration lines. Ifcompactis true, also remove blank lines between declarations in a group. Ifalign_commentsis true, also align!<inline comments within groups.